@@ -46,7 +46,7 @@ void play(gint which){
   if ( sound == FALSE ) return;
 
   /* determine what to play: */
-  char* audiofile;
+  gchar* audiofile = NULL;
   switch ( which ){
   case ALERT:
     audiofile = alert_sound;
