@@ -158,9 +158,17 @@ Filter::init(const char* str, gint new_mode)
   */
   
   regex_pattern = new re_pattern_buffer;
+
+  /*
+    Make a clean start (pun :-) )
+  */
+  regex_pattern->start = NULL;
   regex_pattern->buffer = NULL;
   regex_pattern->allocated = 0;
- 
+  regex_pattern->re_nsub = 0;
+  regex_pattern->se_params = NULL; 
+  regex_pattern->syntax_parens = NULL;
+  
   /*
     set the translation table according to whether the
     user wants case sensitivity
@@ -222,6 +230,11 @@ Filter::init(const char* str, gint new_mode)
       regex_pattern = NULL;
     }
 
+  /*
+    now allocate the syntax_parens
+  */
+  regex_pattern->syntax_parens = new gchar[ regex_pattern->re_nsub + 1 ];
+
   /*
     now create the fastmap if the compilation has been
     successful
