@@ -146,7 +146,7 @@ delete_event(GtkWidget *widget, GdkEvent *event, gpointer data)
   /*
     we do want the user whether he really wants to quit, though...
   */
-  quit(widget, data);
+  quit((GtkWidget*) widget, (gpointer*) data);
 
   return (TRUE);
 }
@@ -502,6 +502,13 @@ disassemble_regex(re_pattern_buffer* regex)
 	  regex->fastmap = NULL;
 	  regex->fastmap_accurate = 0;
 	}
+
+      /* free syntax_parens if the buffer exists */
+      if ( regex->syntax_parens != NULL )
+	{
+	  delete regex->syntax_parens;
+	  regex->syntax_parens = NULL;
+	}
       
       /* free buffer and set to zero if it is used */
       if ( regex->buffer != NULL && regex->allocated != 0 )
@@ -510,7 +517,7 @@ disassemble_regex(re_pattern_buffer* regex)
 	  regex->buffer = NULL;
 	  regex->allocated = 0;
 	}
-    
+      
       delete regex;
     }
   
@@ -807,6 +814,7 @@ init(int argc,char* argv[])
    else if ( ! strcmp( opt, "config" ) )
      {
        if ( optarg == NULL ) usage();
+       fillups = 0;
        read_configuration(optarg);
      }
    else if ( ! strcmp( opt, "fadeseconds" ) )
@@ -925,33 +933,54 @@ init(int argc,char* argv[])
 /*}}}*/
 
 /*{{{  System-wide GTKRC  */
-
- if ( gtkrc == FALSE ){
-   char* gtkrc_fn;
-   gtkrc_fn = new char[ strlen( STYLEDIR ) + strlen( GTKRC ) + 3 ];
-   strcpy(gtkrc_fn, STYLEDIR);
-   strcat(gtkrc_fn, "/");
-   strcat(gtkrc_fn, GTKRC);
-   gtk_rc_parse(gtkrc_fn);
-   delete gtkrc_fn;
- }
+ if ( gtkrc == FALSE )
+   {
+     char* gtkrc_fn;
+     gtkrc_fn = new char[ strlen( STYLEDIR ) + strlen( GTKRC ) + 3 ];
+     strcpy(gtkrc_fn, STYLEDIR);
+     strcat(gtkrc_fn, "/");
+     strcat(gtkrc_fn, GTKRC);
+     gtk_rc_parse(gtkrc_fn);
+     delete gtkrc_fn;
+   }
 /*}}}*/
 
 /*{{{  User specific config file  */
-  if (  fillups == 0 ){
-    char* fname;
-    char* hdir = NULL;
-    hdir = getenv("HOME");
-    if ( hdir == NULL ) hdir = getenv("USER");
-    if ( hdir == NULL ) hdir = getenv("PWD");
-    if ( hdir == NULL ) hdir = ".";
-    fname = new char[ strlen(hdir) + strlen(CONFIGFILE) + 2 ];
-    strcpy ( fname, hdir );
-    strcat ( fname, "/" );
-    strcat ( fname, CONFIGFILE );
-    read_configuration(fname);
-    delete fname;
-  }
+ /*
+   read only if we didn't read an explicit config file
+ */
+ if (  fillups == 0 )
+   {
+     gchar* fname;
+     gchar* hdir = NULL;
+     hdir = getenv("HOME");
+     if ( hdir == NULL ) hdir = getenv("USER");
+     if ( hdir == NULL ) hdir = getenv("PWD");
+     if ( hdir == NULL ) hdir = ".";
+     fname = new gchar[ strlen( hdir ) + strlen( CONFIGFILE ) + 2 ];
+     strcpy ( fname, hdir );
+     strcat ( fname, "/" );
+     strcat ( fname, CONFIGFILE );
+     read_configuration(fname);
+     delete fname;
+   }
+/*}}}*/
+
+/*{{{  System wide config file  */
+  /*
+    read only if we didn't read an explicit or private
+    config file
+  */
+ if (  fillups == 0 )
+   {
+     gchar* fname;     
+     fname = new gchar[ strlen( STYLEDIR ) + strlen( SYSCONFIGFILE ) + 3 ];
+     strcpy ( fname, STYLEDIR );
+     strcat ( fname, "/" );
+     strcat ( fname, SYSCONFIGFILE );
+     read_configuration(fname);
+     delete fname;
+   }
 /*}}}*/
 
 /*{{{  Some logs for new users  */
@@ -1053,7 +1082,7 @@ init(int argc,char* argv[])
      cout << "see the manpage for more information !" << endl;
    } else {
      cout << "success." << endl;
-     cout << "Xlogmaster will not get swapped out." << endl;
+     cout << "The Xlogmaster will not get swapped out." << endl;
    }
  }
 #endif /* HAVE_MLOCKALL */
